@@ -37,6 +37,8 @@ from classiq_interface.pyomo_extension import pyomo
 
 __format_version__ = 1
 
+PyomoObject = Dict  # TODO this probably fits json versions, but generally unrecommended
+
 
 def get_last_object_from_lookup(lookup, object_name) -> Optional[object]:
     for object_lookup in reversed(lookup.values()):
@@ -74,19 +76,15 @@ PYOMO_CLASS_MAPPING = {
 
 
 def _read_component(
-    obj_dict: dict,
+    obj_dict: Dict[Optional[str], Dict[str, Any]],
     store_spec: StoreSpec,
-    lookup: Dict[int, int] = None,
-    suffixes: Dict[Any, Any] = None,
-    root_name: str = None,
+    lookup: Dict[int, PyomoObject],
+    suffixes: Dict[int, Dict[str, int]],
+    root_name: Optional[str] = None,
 ):
     """
     Read a component dictionary into a model
     """
-    if lookup is None:
-        lookup = {}
-    if suffixes is None:
-        suffixes = {}
 
     try:
         root_dict = obj_dict[root_name]
@@ -150,7 +148,10 @@ def _read_component(
 
 
 def _read_component_data(
-    obj_dict: dict, store_spec: StoreSpec, lookup: dict = None, suffixes: dict = None
+    obj_dict: Dict[str, Dict[str, Any]],
+    store_spec: StoreSpec,
+    lookup: Dict[int, PyomoObject],
+    suffixes: Dict[int, Dict[str, int]],
 ) -> dict:
     """
     Read a Pyomo component json_str data in from a dict.
@@ -162,10 +163,6 @@ def _read_component_data(
     Returns:
         Dict
     """
-    if lookup is None:
-        lookup = {}
-    if suffixes is None:
-        suffixes = {}
 
     attr_list = None
     filter_function = None
@@ -271,10 +268,12 @@ def component_data_from_dict(obj_dict, obj, store_spec: StoreSpec):
 
     if may_have_subcomponents(obj):  # read sub-components of block-like
         for _ in obj.component_objects(descend_into=False):
-            _read_component(obj_dict["__pyomo_components__"], store_spec)
+            _read_component(
+                obj_dict["__pyomo_components__"], store_spec, dict(), dict()
+            )
 
 
-def _read_suffixes(lookup: dict, suffixes: dict):
+def _read_suffixes(lookup: Dict[int, PyomoObject], suffixes: Dict[int, Dict[str, int]]):
     """
     Go through the list of suffixes and read the data back in.
     Args:
@@ -357,8 +356,8 @@ def from_json(
     if not store_spec:
         store_spec = StoreSpec()
 
-    lookup: Dict[int, int] = {}
-    suffixes: Dict[Any, Any] = {}
+    lookup: Dict[int, PyomoObject] = dict()
+    suffixes: Dict[int, Dict[str, int]] = dict()
     obj = _read_component(
         obj_dict, store_spec, lookup=lookup, suffixes=suffixes, root_name=root_name
     )
