@@ -1,4 +1,4 @@
-from typing import Dict, Union
+from typing import Dict, Optional, Union
 
 import pydantic
 
@@ -21,7 +21,7 @@ class OptimizationProblem(pydantic.BaseModel):
         default_factory=OptimizerPreferences,
         description="preferences for the VQE execution",
     )
-    serialized_model: Union[Dict, None] = None
+    serialized_model: Optional[Dict] = None
     backend_preferences: Union[
         AzureBackendPreferences, IBMBackendPreferences, AwsBackendPreferences
     ] = pydantic.Field(
@@ -30,7 +30,7 @@ class OptimizationProblem(pydantic.BaseModel):
         ),
         description="Preferences for the requested backend to run the quantum circuit.",
     )
-    encoding_type: EncodingType = pydantic.Field(
+    encoding_type: Optional[EncodingType] = pydantic.Field(
         default_factory=EncodingType.BINARY,
         description="encoding scheme for integer variables",
     )
