@@ -19,7 +19,7 @@ from classiq_interface.generator.arith.binary_ops import (
     RShift,
     Subtractor,
 )
-from classiq_interface.generator.arith.unary_ops import Negation
+from classiq_interface.generator.arith.unary_ops import BitwiseInvert, Negation
 from classiq_interface.generator.credit_risk_example.cdf_comparator import CDFComparator
 from classiq_interface.generator.credit_risk_example.linear_gci import LinearGCI
 from classiq_interface.generator.credit_risk_example.weighted_adder import WeightedAdder
@@ -40,6 +40,9 @@ from classiq_interface.generator.mcx import Mcx
 from classiq_interface.generator.qaoa_ansatz import QaoaAnsatz
 from classiq_interface.generator.qft import QFT
 from classiq_interface.generator.sparse_amp_load import SparseAmpLoad
+from classiq_interface.generator.standard_gates.standard_gates_param_list import (
+    get_qiskit_standard_function_param_list,
+)
 from classiq_interface.generator.state_preparation import StatePreparation
 from classiq_interface.generator.state_propagator import StatePropagator
 from classiq_interface.generator.unitary_gate import UnitaryGate
@@ -55,6 +58,7 @@ _function_param_list = {
     BitwiseAnd,
     BitwiseOr,
     BitwiseXor,
+    BitwiseInvert,
     Adder,
     Arithmetic,
     ArithmeticOracle,
@@ -92,4 +96,6 @@ _function_param_list = {
 
 
 def get_function_param_list() -> Set[Type[FunctionParams]]:
+    qiskit_standard_function_param_list = get_qiskit_standard_function_param_list()
+    _function_param_list.update(qiskit_standard_function_param_list)
     return _function_param_list
