@@ -20,7 +20,7 @@ class HybridMetadata(pydantic.BaseModel):
 
 
 class FinanceMetadata(pydantic.BaseModel):
-    finance_attribute: Union[finance.Finance, FinanceModelMetadata, None]
+    finance_attribute: Optional[Union[finance.Finance, FinanceModelMetadata]]
 
 
 class GroverMetadata(pydantic.BaseModel):
