@@ -1,4 +1,4 @@
-from typing import Optional, Tuple, Generic, TypeVar
+from typing import Generic, Optional, TypeVar
 
 import pydantic
 from pydantic.generics import GenericModel
@@ -23,17 +23,6 @@ class Range(GenericModel, Generic[RangeType]):
 
         return upper_bound
 
-    # TODO: Remove default values
-    def to_tuple(
-        self,
-        default_lower_bound: RangeType = -1,
-        default_upper_bound: RangeType = float("inf"),
-    ) -> Tuple[RangeType, RangeType]:
-        return (
-            self.lower_bound if self.lower_bound else default_lower_bound,
-            self.upper_bound if self.upper_bound else default_upper_bound,
-        )
 
-
-NonNegativeIntRange = Range[pydantic.conint(ge=0)]
-NonNegativeFloatRange = Range[pydantic.confloat(ge=0)]
+NonNegativeIntRange = Range[pydantic.NonNegativeInt]
+NonNegativeFloatRange = Range[pydantic.NonNegativeFloat]
