@@ -1,16 +1,13 @@
-from enum import Enum
-from typing import Type, List
-from classiq_interface.generator.state_preparation import is_power_of_two
-import numpy as np
+from typing import List
 
+import numpy as np
 import pydantic
 
+from classiq_interface.generator import function_params
 from classiq_interface.generator.complex_type import Complex
-from classiq_interface.generator.function_params import FunctionParams
+from classiq_interface.generator.state_preparation import is_power_of_two
 
-
-class SparseAmpLoadOutputs(Enum):
-    OUTPUT_STATE = "OUTPUT_STATE"
+OUTPUT_STATE = "OUTPUT_STATE"
 
 
 def amplitudes_sum_to_one(amp):
@@ -19,7 +16,7 @@ def amplitudes_sum_to_one(amp):
     return amp
 
 
-class SparseAmpLoad(FunctionParams):
+class SparseAmpLoad(function_params.FunctionParams):
     """
     loads a sparse amplitudes vector
     """
@@ -36,4 +33,5 @@ class SparseAmpLoad(FunctionParams):
         amplitudes_sum_to_one
     )
 
-    _output_names: Type[Enum] = pydantic.PrivateAttr(default=SparseAmpLoadOutputs)
+    _input_names = pydantic.PrivateAttr(default_factory=list)
+    _output_names = pydantic.PrivateAttr(default=[OUTPUT_STATE])
